
#!/bin/sh

ROOT_DIR="./"
KMOD_DIR="$ROOT_DIR/kmod"

log()
{
	echo "$1" >>/tmp/log/ipkstore.log
}

uninstall()
{
	local sys_kernel_ver=`uname -a |awk '{print $3}' | awk -F- '{print $1}'`
	/etc/init.d/appfilter stop
	rmmod oaf
	opkg remove luci-i18n-oaf-zh-cn
	opkg remove luci-app-oaf
	opkg remove appfilter
	rm /lib/modules/$sys_kernel_ver/oaf.ko
}

install_ipk()
{
	local ipk_name=$1
	if [ x"" == x"$ipk_name" ];then
		return
	fi
	ipk=`ls  |grep ^$ipk_name`
	if [ x"" == x"$ipk" ];then
		log "$ipk_name not exist"
		return
	fi
	opkg install $ipk
}


install()
{
	local appfilter_ipk
	local kmod_ipk
	local luci_ipk
	local luci_i18n_ipk
	local sys_kernel_ver
	! test -d $ROOT_DIR && return
	echo "ROOT_DIR:$ROOT_DIR"
	cd $ROOT_DIR
	
	sys_kernel_ver=`uname -a |awk '{print $3}' | awk -F- '{print $1}'`

	kmod_ipk=`ls  |grep kmod-oaf`
	if [ x"" == x"$kmod_ipk" ];then
		log "kmod ipk error, not found kmod-oaf"
		return 1
	fi

	kernel_ver=`ls  |grep kmod-oaf | awk -F_ '{print $2}'| awk -F- '{print $1}'`
	if [ x"" == x"$kernel_ver" ];then
		log "kernel version error, ipk name error"
		return 1
	fi

	echo "ipk:$kmod_ipk, kernel version:$kernel_ver"

	! test -e $KMOD_DIR && mkdir $KMOD_DIR

	tar -zxvf $kmod_ipk -C $KMOD_DIR
	tar -zxvf $KMOD_DIR/data.tar.gz -C $KMOD_DIR

	touch /tmp/feature.cfg
	echo "">/tmp/feature.cfg
	insmod $KMOD_DIR/lib/modules/$kernel_ver/oaf.ko
	
	if [ $? -ne 0 ];then
		log "install kmod-oaf failed, kmod-oaf ver:$kernel_ver system kernel ver:$sys_kernel_ver"
		return 1
	fi
	cp $KMOD_DIR/lib/modules/$kernel_ver/oaf.ko /lib/modules/$sys_kernel_ver/
	log "force install kmod-oaf ipk ok..."

	install_ipk "libubox"
	install_ipk "libubus"
	install_ipk "libblobmsg"
	install_ipk "appfilter"
	if [ $? -ne 0 ];then
		log "install appfilter ipk failed..."
		return 1
	else
		log "install appfilter ipk ok..."
	fi
	install_ipk "luci-app-oaf"
	if [ $? -ne 0 ];then
		log "install luci-app-oaf ipk failed..."
		return 1
	else
		log "install luci-app-oaf ipk ok..."
	fi
	install_ipk "luci-i18n-oaf-zh-cn"
	if [ $? -ne 0 ];then
		log "install luci-i18n-oaf-zh-cn ipk failed..."
		return 1
	else
		log "install luci-i18n-oaf-zh-cn ipk ok..."
	fi
	return 0
}

action=$1
case $action in
"install")
	echo "install..."
	install
	if [ $? -eq 0 ];then
		/etc/init.d/appfilter restart
		return 0
	else
		return 1
	fi
	
;;
"uninstall")
	echo "uninstall..."
	uninstall
	if [ $? -eq 0 ];then
		return 0
	else
		return 1
	fi
;;
*)
	echo "param error"
;;
esac
return 0








